@@ -2,21 +2,16 @@
 #######################################################################
 """Dwitchable markers
 
-$Id: interfaces.py 51921 2008-10-21 19:07:20Z cray $
+$Id: interfaces.py 51965 2008-10-23 21:55:22Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 51921 $"
-__date__ = "$Date: 2008-10-21 23:07:20 +0400 (Втр, 21 Окт 2008) $"
+__version__ = "$Revision: 51965 $"
+__date__ = "$Date: 2008-10-24 01:55:22 +0400 (Птн, 24 Окт 2008) $"
  
-from ks.interfaceswitcher.interfaces import IInterfaceSwitcherAble
-from ng.content.article.interfaces import IDocFormatSwitcher
+from ng.content.article.interfaces import IDocFormatSwitcher, IArticleDesignSwitcher
+from zope.interface import Interface
 
-class IArticleDesignSwitcher(IInterfaceSwitcherAble):
-    "Default Design"
-    pass
-
-    
 class IArticleDivided(IArticleDesignSwitcher) :
     "Divided Design"
     pass
@@ -42,7 +37,7 @@ class IArticleHTML(IDocFormatSwitcher):
     pass
 
 
-class IDivisionDesignSwitcher(IInterfaceSwitcherAble):
+class IDivisionDesignSwitcher(Interface):
     "Default Design"
     pass
 
